@@ -14,7 +14,7 @@ use Unicode::UTF8 qw(encode_utf8 decode_utf8);
 
 Readonly::Array our @OUTPUT_FORMATS => qw(ascii xml);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -40,8 +40,9 @@ sub run {
 		'o' => 'xml',
 		'r' => 0,
 	};
-	if (! getopts('ho:r', $self->{'_opts'}) || @ARGV < 4
-		|| $self->{'_opts'}->{'h'}) {
+	if (! getopts('ho:r', $self->{'_opts'})
+		|| $self->{'_opts'}->{'h'}
+		|| @ARGV < 4) {
 
 		print STDERR "Usage: $0 [-h] [-o format] [-r] [--version] marc_xml_file field subfield value\n";
 		print STDERR "\t-h\t\tPrint help.\n";
@@ -456,12 +457,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2022 Michal Josef Špaček
+© 2022-2024 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
